@@ -36,7 +36,7 @@ void SmtpTest::testHello_data()
              << "C: EHLO 127.0.0.1"
              << "S: 250 Localhost ready to roll"
              << FakeServer::bye();
-    QTest::newRow("EHLO OK") << scenario << QString();
+    QTest::newRow("EHLO OK") << scenario << QStringLiteral("127.0.0.1");
 
     scenario.clear();
     scenario << FakeServer::greeting()
@@ -45,7 +45,7 @@ void SmtpTest::testHello_data()
              << "C: HELO 127.0.0.1"
              << "S: 250 Localhost ready to roll"
              << FakeServer::bye();
-    QTest::newRow("EHLO unknown") << scenario << QString();
+    QTest::newRow("EHLO unknown") << scenario << QStringLiteral("127.0.0.1");
 
     scenario.clear();
     scenario << FakeServer::greeting()
@@ -54,7 +54,7 @@ void SmtpTest::testHello_data()
              << "C: HELO 127.0.0.1"
              << "S: 250 Localhost ready to roll"
              << FakeServer::bye();
-    QTest::newRow("EHLO not implemented") << scenario << QString();
+    QTest::newRow("EHLO not implemented") << scenario << QStringLiteral("127.0.0.1");
 
     scenario.clear();
     scenario << FakeServer::greeting()
@@ -63,7 +63,7 @@ void SmtpTest::testHello_data()
              << "C: HELO 127.0.0.1"
              << "S: 500 Command was not recognized"
              << FakeServer::bye();
-    QTest::newRow("ERROR") << scenario << QString();
+    QTest::newRow("ERROR") << scenario << QStringLiteral("127.0.0.1");
 
     scenario.clear();
     scenario << FakeServer::greeting()
@@ -167,6 +167,7 @@ void SmtpTest::testLoginJob()
     fakeServer.setScenario(scenario);
     fakeServer.startAndWait();
     KSmtp::Session session(QStringLiteral("127.0.0.1"), 5989);
+    session.setCustomHostname(QStringLiteral("127.0.0.1"));
     session.openAndWait();
 
     KSmtp::LoginJob *login = new KSmtp::LoginJob(&session);
@@ -211,7 +212,15 @@ void SmtpTest::testSendJob_data()
              << "S: 250 ok"
              << "C: DATA"
              << "S: 354 Ok go ahead"
-             << "C: SKIP"
+             << "C: From: foo@bar.com"
+             << "C: To: bar@foo.com"
+             << "C: Hello world."
+             << "C: .." // Single dot becomes two
+             << "C: .." // Single dot becomes two
+             << "C: ..." // Two dots become three
+             << "C: ..Foo"  // .Foo becomes ..Foo
+             << "C: End"
+             << "C: "
              << "C: ."
              << "S: 250 Ok transfer done"
              << FakeServer::bye();
@@ -230,19 +239,17 @@ void SmtpTest::testSendJob()
     fakeServer.setScenario(scenario);
     fakeServer.startAndWait();
     KSmtp::Session session(QStringLiteral("127.0.0.1"), 5989);
+    session.setCustomHostname(QStringLiteral("127.0.0.1"));
     session.openAndWait();
 
     KSmtp::SendJob *send = new KSmtp::SendJob(&session);
-
-    KMime::Message::Ptr m(new KMime::Message());
-    m->from()->fromUnicodeString(QStringLiteral("Foo Bar <foo@bar.com>"), "utf-8");
-    m->to()->fromUnicodeString(QStringLiteral("Bar Foo <bar@foo.com>"), "utf-8");
-    m->subject()->fromUnicodeString(QStringLiteral("Subject"), "utf-8");
-    send->setMessage(m);
+    send->setData("From: foo@bar.com\r\nTo: bar@foo.com\r\nHello world.\r\n.\r\n.\r\n..\r\n.Foo\r\nEnd");
+    send->setFrom(QStringLiteral("foo@bar.com"));
+    send->setTo({QStringLiteral("bar@foo.com")});
     send->exec();
 
     // Checking job error code:
-    QVERIFY2(send->error() == errorCode, "Unexpected LoginJob error code");
+    QVERIFY2(send->error() == errorCode, qPrintable(QStringLiteral("Unexpected LoginJob error: ") + send->errorString()));
 
     session.quitAndWait();
 
