@@ -25,6 +25,9 @@
 
 #include <KLocalizedString>
 
+#include <QJsonDocument>
+#include <QJsonObject>
+
 extern "C" {
 #include <sasl/sasl.h>
 }
@@ -121,14 +124,14 @@ void LoginJob::setPreferedAuthMode(AuthMode mode)
     d->m_preferedAuthMode = mode;
 }
 
+LoginJob::AuthMode LoginJob::usedAuthMode() const
+{
+    return d_func()->m_actualAuthMode;
+}
+
 void LoginJob::setEncryptionMode(EncryptionMode mode)
 {
     Q_D(LoginJob);
-    if (mode == SslV2 || mode == SslV3 || mode == TlsV1SslV3 || mode == AnySslVersion) {
-        mode = SSLorTLS;
-    } else if (mode == TlsV1) {
-        mode = STARTTLS;
-    }
     d->m_encryptionMode = mode;
 }
 
@@ -155,6 +158,7 @@ void LoginJob::doStart()
         } else {
             qCWarning(KSMTP_LOG) << "STARTTLS not supported by the server!";
             setError(KJob::UserDefinedError);
+            setErrorText(i18n("STARTTLS is not supported by the server, try using SSL/TLS instead."));
             emitResult();
         }
     } else {
@@ -241,17 +245,21 @@ bool LoginJobPrivate::sasl_interact()
     while (interact->id != SASL_CB_LIST_END) {
         qCDebug(KSMTP_LOG) << "SASL_INTERACT Id" << interact->id;
         switch (interact->id) {
-        case SASL_CB_AUTHNAME:
+        case SASL_CB_AUTHNAME: {
         //case SASL_CB_USER:
             qCDebug(KSMTP_LOG) << "SASL_CB_[USER|AUTHNAME]: '" << m_userName << "'";
-            interact->result = strdup(m_userName.toUtf8().constData());
-            interact->len = strlen((const char *) interact->result);
+            const auto username = m_userName.toUtf8();
+            interact->result = strdup(username.constData());
+            interact->len = username.size();
             break;
-        case SASL_CB_PASS:
+        }
+        case SASL_CB_PASS: {
             qCDebug(KSMTP_LOG) << "SASL_CB_PASS: [hidden]";
-            interact->result = strdup(m_password.toUtf8().constData());
-            interact->len = strlen((const char *) interact->result);
+            const auto pass = m_password.toUtf8();
+            interact->result = strdup(pass.constData());
+            interact->len = pass.size();
             break;
+        }
         default:
             interact->result = nullptr;
             interact->len = 0;
@@ -269,6 +277,21 @@ bool LoginJobPrivate::sasl_challenge(const QByteArray &challenge)
     const char *out = nullptr;
     uint outLen = 0;
 
+    if (m_actualAuthMode == LoginJob::XOAuth2) {
+        QJsonDocument doc = QJsonDocument::fromJson(challenge);
+        if (!doc.isNull() && doc.isObject()) {
+            const auto obj = doc.object();
+            if (obj.value(QLatin1String("status")).toString() == QLatin1String("400")) {
+                q->setError(LoginJob::TokenExpired);
+                q->setErrorText(i18n("Token expired"));
+                // https://developers.google.com/gmail/imap/xoauth2-protocol#error_response_2
+                // "The client sends an empty response ("\r\n") to the challenge containing the error message."
+                q->sendCommand("");
+                return false;
+            }
+        }
+    }
+
     Q_FOREVER {
         result = sasl_client_step(m_saslConn, challenge.isEmpty() ? nullptr : challenge.constData(),
                                   challenge.size(), &m_saslClient, &out, &outLen);
@@ -374,8 +397,8 @@ LoginJob::AuthMode LoginJobPrivate::authModeFromCommand(const QByteArray &mech)
         return LoginJob::NTLM;
     } else if (qstrnicmp(mech.constData(), "ANONYMOUS", 9) == 0) {
         return LoginJob::Anonymous;
-    } else if (qstrnicmp(mech.constData(), "XOAUTH", 6) == 0) {
-        return LoginJob::XOAuth;
+    } else if (qstrnicmp(mech.constData(), "XOAUTH2", 7) == 0) {
+        return LoginJob::XOAuth2;
     } else {
         return LoginJob::UnknownAuth;
     }
@@ -398,8 +421,8 @@ QByteArray LoginJobPrivate::authCommand(LoginJob::AuthMode mode) const
         return QByteArrayLiteral("NTLM");
     case LoginJob::Anonymous:
         return QByteArrayLiteral("ANONYMOUS");
-    case LoginJob::XOAuth:
-        return QByteArrayLiteral( "XOAUTH");
+    case LoginJob::XOAuth2:
+        return QByteArrayLiteral("XOAUTH2");
     case LoginJob::UnknownAuth:
         return ""; // Should not happen
     }
