@@ -41,8 +41,8 @@ public:
     explicit SessionThread(const QString &hostName, quint16 port, Session *session);
     ~SessionThread() override;
 
-    QString hostName() const;
-    quint16 port() const;
+    Q_REQUIRED_RESULT QString hostName() const;
+    Q_REQUIRED_RESULT quint16 port() const;
 
     void setUseNetworkProxy(bool useProxy);
 
